
angular.module('beamng.apps')
.directive('classicGearsDark', ['StreamsManager', 'bngApi', function (StreamsManager, bngApi) {
  return {
    template: '<div style="overflow: hidden;"><canvas id="cGearsDark"></canvas></div>',
    replace: true,
    restrict: 'EA',
    link: function (scope, element, attrs) {
        
        var streams = ['engineInfo', 'electrics'];
        StreamsManager.add(streams);
        scope.$on('$destroy', function () {
            StreamsManager.remove(streams);
        });

        var canvas = element.find("canvas")[0];
            
        var values = [];

        var gearType = "";
        var gearNames = ["P","R","N","D","2","1"];
        var gearNumStr, gearDirStr;

        scope.$on('streamsUpdate', function (event, streams) {
            canvas.width = element[0].clientWidth;
            canvas.height = canvas.width / 1.4444;

            var aGear = Math.round(streams.electrics.gear_A*5);
            var mGear = streams.engineInfo[5];
            var maxFGears = streams.engineInfo[6];
            var maxRGears = streams.engineInfo[7];

            try {
                if(gearType == "manualGearbox") {
                    //get the sign of the current manual gear
                    var sign = mGear?mGear<0?-1:1:0;

                    //get the direction
                    if (sign == -1) {
                        if(mGear < 0 && maxRGears == 1) {
                            gearDirStr = "";
                        } else {
                            gearDirStr = "R";
                        }
                    } else if (sign == 1) {
                        gearDirStr = "F";
                    } else {
                        gearDirStr = "";
                    }

                    //get the gear number
                    if (mGear > 0) {
                        gearNumStr = Math.abs(mGear) + "/" + maxFGears;
                    } else if (mGear < 0 && maxRGears > 1) {
                        gearNumStr = Math.abs(mGear) + "/" + maxRGears;
                    } else if (mGear < 0 && maxRGears == 1) {
                        gearNumStr = "R";
                    } else {
                        gearNumStr = "N";
                    }

                } else if(gearType == "dctGearbox") {
                    gearNumStr = streams.engineInfo[5];
                    gearDirStr = "";
                } else {
                    gearNumStr = streams.electrics.gear;
                    gearDirStr = "";
                }
            } catch(e) {
                //error, fallback!
                gearNumStr = streams.electrics.gear;
                gearDirStr = "";
            }

            var w = canvas.width;
            var h = canvas.height;
            var scale = w / 100;

            //console.log(scale);

            var ctx = canvas.getContext('2d');

            ctx.scale(scale, scale);
            ctx.clearRect(0, 0, w, h);
            ctx.fillStyle = "rgba(0, 0, 0, 0.9)";
            ctx.fillRect(0, 0, w, h);

            if(streams.engineInfo) {
                ctx.fillStyle = "rgb(220, 220, 220)";
                ctx.textAlign="center";
                ctx.font='30px Arial';
                ctx.fillText(gearNumStr, 50, 34);
                ctx.font='12px Arial';
                ctx.fillText(gearDirStr, 50, 50);

                ctx.fillStyle = "white";
                ctx.textAlign="center";
                ctx.font='10px Arial';

                var trans = gearType=="manualGearbox"?"Manual":"Automatic";
                trans = gearType=="dctGearbox"?"DCT":trans;
                trans = gearType=="electric"?"Electric":trans;
                ctx.fillText("Gears (" + trans + ")", 50, 62);

            }

        });


        scope.$on('VehicleReset', function (_, data) {
        	scope.updateGearbox();
        });

        scope.$on('VehicleFocusChanged', function (_, data) {
        	scope.updateGearbox();
        });

        scope.updateGearbox = function() {
			try {
        		var exec = `powertrain.getDevice("gearbox")==null and "electric" or powertrain.getDevice("gearbox").type`;
	            bngApi.activeObjectLua(exec, function(data) {
					gearType = data;
	            });
	        } catch(e) {
	        	console.log("error");
	        }
        };
        
        scope.updateGearbox();

        function pad(num, size) {
            var s = num+"";
            while (s.length < size) s = "0" + s;
            return s;
        }
    }
  };
}]);
